(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     18636,        532]
NotebookOptionsPosition[     17407,        486]
NotebookOutlinePosition[     17753,        501]
CellTagsIndexPosition[     17710,        498]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Initialization", "Section",
 CellChangeTimes->{{3.5281400847886887`*^9, 3.5281400869008093`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"google", " ", "static", " ", "map", " ", "api"}], " ", "*)"}], 
  "\[IndentingNewLine]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"googleMap", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"lat_", ",", "lon_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"sizex_", ",", "sizey_"}], "}"}], ",", "zoom_", ",", 
       "maptype_"}], "]"}], ":=", 
     RowBox[{"Import", "[", 
      RowBox[{
      "\"\<http://maps.google.com/maps/api/staticmap?sensor=false&center=\>\"\
", "<>", 
       RowBox[{"ToString", "[", "lat", "]"}], "<>", "\"\<,\>\"", "<>", 
       RowBox[{"ToString", "[", "lon", "]"}], "<>", "\"\<&zoom=\>\"", "<>", 
       RowBox[{"ToString", "[", "zoom", "]"}], "<>", "\"\<&size=\>\"", "<>", 
       RowBox[{"ToString", "[", "sizex", "]"}], "<>", "\"\<x\>\"", "<>", 
       RowBox[{"ToString", "[", "sizey", "]"}], "<>", "\"\<&maptype=\>\"", "<>",
        "maptype"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"convert", " ", "lat", " ", "2", " ", "y"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"lat2y", "[", "lat_", "]"}], ":=", 
     RowBox[{"0.5", 
      RowBox[{"Log", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"Sin", "[", 
           RowBox[{"lat", " ", "Degree"}], "]"}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"Sin", "[", 
           RowBox[{"lat", " ", "Degree"}], "]"}]}], ")"}]}], "]"}]}]}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"convert", " ", "y", " ", "2", " ", "lat"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"y2lat", "[", "y_", "]"}], ":=", 
     RowBox[{
      RowBox[{"Gudermannian", "[", "y", "]"}], "*", 
      RowBox[{"180", "/", "Pi"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "caculate", " ", "parameters", " ", "for", " ", "google", " ", "map"}], 
    " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gMapPara", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"lon1_", ",", "lat1_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"lon2_", ",", "lat2_"}], "}"}]}], "}"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "nx", ",", "ny", ",", "sizex", ",", "sizey", ",", "zoom", ",", 
        "lonspan", ",", "latspan", ",", 
        RowBox[{"maxmapsize", "=", "640"}]}], "}"}], ",", 
      RowBox[{
       RowBox[{"nx", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"lon1", "+", "lon2"}], ")"}], "/", "2"}]}], ";", 
       RowBox[{"ny", "=", 
        RowBox[{"y2lat", "[", 
         RowBox[{"0.5", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"lat2y", "[", "lat1", "]"}], "+", 
            RowBox[{"lat2y", "[", "lat2", "]"}]}], ")"}]}], "]"}]}], ";", 
       RowBox[{"lonspan", "=", 
        RowBox[{"Abs", "@", 
         RowBox[{"(", 
          RowBox[{"lon1", "-", "lon2"}], ")"}]}]}], ";", 
       RowBox[{"latspan", "=", 
        RowBox[{"Abs", "@", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"lat1", "-", "lat2"}], ")"}], " ", "/", 
           RowBox[{"Cos", "[", 
            RowBox[{"ny", " ", "Degree"}], "]"}]}], ")"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"zoom", " ", "=", 
        RowBox[{"1", "+", " ", 
         RowBox[{"Floor", "[", 
          RowBox[{"Log", "[", 
           RowBox[{"2", ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"180", "/", 
               RowBox[{"Max", "[", 
                RowBox[{"{", 
                 RowBox[{"lonspan", ",", "latspan"}], "}"}], "]"}]}], ")"}], 
             "*", 
             RowBox[{"(", 
              RowBox[{"maxmapsize", "/", "256.0"}], ")"}]}]}], "]"}], 
          "]"}]}]}], ";", " ", 
       RowBox[{"sizex", "=", 
        RowBox[{"Ceiling", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Abs", "@", 
            RowBox[{"(", 
             RowBox[{"lon1", "-", "lon2"}], ")"}]}], "/", "360"}], "*", "256",
           "*", 
          RowBox[{"2", "^", "zoom"}]}], "]"}]}], ";", 
       RowBox[{"sizey", "=", 
        RowBox[{"Ceiling", "[", 
         RowBox[{"2", "*", "256.0", "*", 
          RowBox[{
           RowBox[{"2", "^", "zoom"}], "/", 
           RowBox[{"(", 
            RowBox[{"2", "*", "Pi"}], ")"}]}], "*", 
          RowBox[{"Abs", "@", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"lat2y", "[", "ny", "]"}], "-", 
             RowBox[{"lat2y", "[", "lat1", "]"}]}], ")"}]}]}], "]"}]}], ";", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"ny", ",", "nx"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"sizex", ",", "sizey"}], "}"}], ",", "zoom"}], "}"}]}]}], 
     "]"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.497610375427382*^9, 3.4976109484711585`*^9}, {
  3.4976110362961817`*^9, 3.497611037944276*^9}, {3.497611194281218*^9, 
  3.4976112576578426`*^9}, {3.4976113507631683`*^9, 3.4976113637549114`*^9}, {
  3.4976114645886784`*^9, 3.497611504859982*^9}, {3.497611598278325*^9, 
  3.497611601526511*^9}, {3.4976131309839907`*^9, 3.497613132153058*^9}, {
  3.497613486652334*^9, 3.4976135061034465`*^9}, {3.49761369550128*^9, 
  3.4976138033884506`*^9}, {3.4976138617567887`*^9, 3.4976139578632855`*^9}, {
  3.4976140442162247`*^9, 3.497614044791258*^9}, {3.4976146665878224`*^9, 
  3.4976146790225334`*^9}, {3.4976153550532007`*^9, 3.497615358476396*^9}, {
  3.497615388589119*^9, 3.4976153943924503`*^9}, {3.4976159263008738`*^9, 
  3.497615932091205*^9}, {3.497616968824503*^9, 3.49761698468441*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "kmlSnippet", "=", 
   "\"\<<?xml version=\\\"1.0\\\" encoding=\\\"UTF-8\\\"?>\n<kml \
xmlns=\\\"http://www.opengis.net/kml/2.2\\\">\n\n<Document>\n  <Camera>\n    \
<longitude>-122.444633</longitude>\n    <latitude>37.801899</latitude>\n    \
<altitude>139.629438</altitude>\n    <heading>-70.0</heading>\n    \
<tilt>75</tilt>\n  </Camera>\n\n  <Placemark>\n    <name>Google Earth - \
Mathematica Integration!</name>\n    <Point>\n      \
<coordinates>-112.111,36.0925,0</coordinates>\n    </Point>\n  </Placemark>\n\
\n</Document> \n</kml>\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.528131822741127*^9, 3.5281318324406815`*^9}, 
   3.528131981257193*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bbox", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Reverse", "[", 
     RowBox[{"{", 
      RowBox[{"36.143236", ",", " ", 
       RowBox[{"-", "112.188808"}]}], "}"}], "]"}], ",", 
    RowBox[{"Reverse", "[", 
     RowBox[{"{", 
      RowBox[{"36.041676", ",", 
       RowBox[{"-", "112.032304"}]}], "}"}], "]"}]}], "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5281208498365126`*^9, 3.5281209081088457`*^9}, {
  3.528120995388838*^9, 3.5281210040443325`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "112.188808`"}], ",", "36.143236`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "112.032304`"}], ",", "36.041676`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5281209088928905`*^9, 3.5281210045383606`*^9, 
  3.528142975282016*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"center", ",", "size", ",", "zoom"}], "}"}], "=", 
  RowBox[{"gMapPara", "[", "bbox", "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"36.09247240464975`", ",", 
     RowBox[{"-", "112.110556`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"456", ",", "367"}], "}"}], ",", "12"}], "}"}]], "Output",
 CellChangeTimes->{3.5281209376945376`*^9, 3.5281210072895184`*^9, 
  3.5281429753720207`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"gImg", "=", 
  RowBox[{"googleMap", "[", 
   RowBox[{"center", ",", "size", ",", "zoom", ",", "\"\<terrain\>\""}], 
   "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"produceKML", "[", "coordinates_List", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "outputKML", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"outputKML", "=", 
      RowBox[{"StringReplace", "[", 
       RowBox[{"kmlSnippet", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\"\<<longitude>-122.444633</longitude>\>\"", "\[Rule]", 
           RowBox[{"\"\<<longitude>\>\"", "<>", 
            RowBox[{"ToString", "[", 
             RowBox[{"coordinates", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "]"}], "<>", 
            "\"\<</longitude>\>\""}]}], ",", 
          RowBox[{"\"\<<latitude>37.801899</latitude>\>\"", "\[Rule]", 
           RowBox[{"\"\<<latitude>\>\"", "<>", 
            RowBox[{"ToString", "[", 
             RowBox[{"coordinates", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "]"}], "<>", 
            "\"\<</latitude>\>\""}]}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Export", "[", 
      RowBox[{"kmlDestination", ",", "outputKML", ",", "\"\<Text\>\""}], 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5281318655625763`*^9, 3.5281319708866005`*^9}, {
  3.5281361977103605`*^9, 3.52813637131229*^9}, {3.528137452682141*^9, 
  3.5281374760734787`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"processViewPoint", "[", "viewPoint_List", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"log", ",", "lat", ",", "range", ",", "center"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"range", "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"bbox", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", 
         RowBox[{"bbox", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "/", "2"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"center", "=", 
      RowBox[{
       RowBox[{"bbox", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "+", "range"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"produceKML", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"range", "*", 
         RowBox[{"-", "viewPoint"}]}], ")"}], "+", "center"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"N", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"range", "*", 
          RowBox[{"-", "viewPoint"}]}], ")"}], "+", "center"}], ",", "20"}], 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.528126626490918*^9, 3.5281266844862356`*^9}, {
   3.528126747293828*^9, 3.5281267801827087`*^9}, {3.52812770910284*^9, 
   3.5281277396945896`*^9}, {3.5281280309112463`*^9, 3.5281280318463*^9}, {
   3.5281280663672743`*^9, 3.52812806647128*^9}, {3.5281281001762085`*^9, 
   3.5281281564984293`*^9}, {3.5281282334798326`*^9, 
   3.5281282626705027`*^9}, {3.528128403697569*^9, 3.5281284302800894`*^9}, {
   3.5281290739519053`*^9, 3.528129074079912*^9}, 3.528129272984289*^9, {
   3.528129807583866*^9, 3.5281298106950445`*^9}, {3.528129843359913*^9, 
   3.52812984348792*^9}, {3.5281382271054354`*^9, 3.5281382405062017`*^9}, {
   3.5281399921203885`*^9, 3.5281399924084053`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Use to control KML creation", "Section",
 CellChangeTimes->{{3.528140103500759*^9, 3.528140110628167*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "kmlDestination", "=", 
   "\"\<C:\\\\Documents and Settings\\\\George Danner\\\\My Documents\\\\My \
Dropbox\\\\Public\\\\refresh.kml\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.528131873762045*^9, 3.5281318847816753`*^9}, 
   3.5281383477243347`*^9, {3.528143133621072*^9, 3.528143145749766*^9}}],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Grid", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{"Graphics", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Inset", "[", 
           RowBox[{"Image", "[", 
            RowBox[{"image", ",", 
             RowBox[{"ImageSize", "\[Rule]", 
              RowBox[{"ImageDimensions", "[", "image", "]"}]}]}], "]"}], 
           "]"}], "}"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "1"}], ",", 
         RowBox[{"ImageSize", "\[Rule]", 
          RowBox[{"ImageDimensions", "[", "image", "]"}]}]}], "]"}], 
       "\[IndentingNewLine]", "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"processViewPoint", "[", "viewPt", "]"}], "}"}]}], "}"}], 
    "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"viewPt", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", "Locator", ",", 
     RowBox[{"ContinuousAction", "\[Rule]", "False"}]}], "}"}], ",", 
   RowBox[{"ControllerLinking", "\[Rule]", "False"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Initialization", "\[RuleDelayed]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"image", "=", "gImg"}], ";"}], ")"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5281259838281603`*^9, 3.528126004392336*^9}, {
  3.5281260368891945`*^9, 3.528126127136357*^9}, {3.52812659138391*^9, 
  3.5281266078398514`*^9}, {3.5281266898725433`*^9, 3.528126711015753*^9}, {
  3.528127957905071*^9, 3.5281280051847754`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Use to create CDF for mimicing behavior\
\>", "Section",
 CellChangeTimes->{{3.5281401233408937`*^9, 3.528140131452358*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"simProcessViewPoint", "[", "viewPoint_List", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"log", ",", "lat", ",", "range", ",", "center"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"range", "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"bbox", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", 
         RowBox[{"bbox", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "/", "2"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"center", "=", 
      RowBox[{
       RowBox[{"bbox", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "+", "range"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"N", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"range", "*", 
          RowBox[{"-", "viewPoint"}]}], ")"}], "+", "center"}], ",", "20"}], 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.528139971113187*^9, 3.528139987439121*^9}}],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Grid", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{"Graphics", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Inset", "[", 
           RowBox[{"Image", "[", 
            RowBox[{"image", ",", 
             RowBox[{"ImageSize", "\[Rule]", 
              RowBox[{"ImageDimensions", "[", "image", "]"}]}]}], "]"}], 
           "]"}], "}"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "1"}], ",", 
         RowBox[{"ImageSize", "\[Rule]", 
          RowBox[{"ImageDimensions", "[", "image", "]"}]}]}], "]"}], 
       "\[IndentingNewLine]", "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"simProcessViewPoint", "[", "viewPt", "]"}], "}"}]}], "}"}], 
    "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"viewPt", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", "Locator", ",", 
     RowBox[{"ContinuousAction", "\[Rule]", "False"}]}], "}"}], ",", 
   RowBox[{"ControllerLinking", "\[Rule]", "False"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Initialization", "\[RuleDelayed]", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"image", "=", "null"}], ";"}], ")"}], "SaveDefinitions"}], 
     "\[Rule]", "True"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5281400134006057`*^9, 3.5281400402651424`*^9}, 
   3.5281429527977295`*^9, {3.5281432525868764`*^9, 3.5281432553690357`*^9}}]
}, Open  ]]
},
WindowSize->{784, 808},
WindowMargins->{{398, Automatic}, {Automatic, 47}},
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (February 23, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 103, 1, 71, "Section"],
Cell[685, 25, 5832, 150, 372, "Input",
 InitializationCell->True],
Cell[6520, 177, 725, 14, 432, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[7270, 195, 510, 14, 31, "Input",
 InitializationCell->True],
Cell[7783, 211, 347, 11, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8167, 227, 182, 5, 31, "Input",
 InitializationCell->True],
Cell[8352, 234, 329, 9, 30, "Output"]
}, Open  ]],
Cell[8696, 246, 188, 5, 31, "Input",
 InitializationCell->True],
Cell[8887, 253, 1372, 31, 172, "Input",
 InitializationCell->True],
Cell[10262, 286, 1901, 46, 132, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[12200, 337, 112, 1, 71, "Section"],
Cell[12315, 340, 365, 8, 52, "Input",
 InitializationCell->True],
Cell[12683, 350, 1766, 45, 172, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14486, 400, 134, 3, 71, "Section"],
Cell[14623, 405, 1035, 30, 112, "Input"],
Cell[15661, 437, 1730, 46, 172, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
